pub struct LocalProjectService<RS: RepoService, ES: EcosystemService, SS: SourceService, FS: RootFacetService, OS: OutputService> {
pub repo_service: RS,
pub ecosystem_service: ES,
pub source_service: SS,
pub facet_service: FS,
pub output_service: OS,
}Expand description
The LocalProjectService struct provides an implementation of the ProjectService trait for initializing
and managing a Skootrs project on the local machine.
Fields
repo_service: RSecosystem_service: ESsource_service: SSfacet_service: FSoutput_service: OSTrait Implementations
Sourceimpl<RS: Debug + RepoService, ES: Debug + EcosystemService, SS: Debug + SourceService, FS: Debug + RootFacetService, OS: Debug + OutputService> Debug for LocalProjectService<RS, ES, SS, FS, OS>
impl<RS: Debug + RepoService, ES: Debug + EcosystemService, SS: Debug + SourceService, FS: Debug + RootFacetService, OS: Debug + OutputService> Debug for LocalProjectService<RS, ES, SS, FS, OS>
Sourceimpl<RS, ES, SS, FS, OS> ProjectService for LocalProjectService<RS, ES, SS, FS, OS>where
RS: RepoService + Send + Sync,
ES: EcosystemService + Send + Sync,
SS: SourceService + Send + Sync,
FS: RootFacetService + Send + Sync,
OS: OutputService + Send + Sync,
impl<RS, ES, SS, FS, OS> ProjectService for LocalProjectService<RS, ES, SS, FS, OS>where
RS: RepoService + Send + Sync,
ES: EcosystemService + Send + Sync,
SS: SourceService + Send + Sync,
FS: RootFacetService + Send + Sync,
OS: OutputService + Send + Sync,
Sourceasync fn initialize(
&self,
params: ProjectCreateParams,
) -> Result<InitializedProject, SkootError>
async fn initialize( &self, params: ProjectCreateParams, ) -> Result<InitializedProject, SkootError>
Initializes a Skootrs project. Read more
Sourceasync fn get(
&self,
params: ProjectGetParams,
) -> Result<InitializedProject, SkootError>
async fn get( &self, params: ProjectGetParams, ) -> Result<InitializedProject, SkootError>
Gets an initialized project. Read more
Sourceasync fn get_facet_with_content(
&self,
params: FacetGetParams,
) -> Result<InitializedFacet, SkootError>
async fn get_facet_with_content( &self, params: FacetGetParams, ) -> Result<InitializedFacet, SkootError>
Gets a facet along with its content from an initialized project. Read more
async fn update( &self, params: ProjectUpdateParams, ) -> Result<InitializedProject, SkootError>
Sourceasync fn outputs_list(
&self,
params: ProjectOutputsListParams,
) -> Result<Vec<ProjectOutputReference>, SkootError>
async fn outputs_list( &self, params: ProjectOutputsListParams, ) -> Result<Vec<ProjectOutputReference>, SkootError>
Lists the outputs of an initialized project. Read more
Sourceasync fn list_facets(
&self,
params: ProjectGetParams,
) -> Result<Vec<FacetMapKey>, SkootError>
async fn list_facets( &self, params: ProjectGetParams, ) -> Result<Vec<FacetMapKey>, SkootError>
Lists the facets of an initialized project. Read more
async fn output_get( &self, params: ProjectOutputGetParams, ) -> Result<ProjectOutput, SkootError>
Sourceasync fn archive(
&self,
params: ProjectArchiveParams,
) -> Result<String, SkootError>
async fn archive( &self, params: ProjectArchiveParams, ) -> Result<String, SkootError>
Archives an initialized project. Read more